/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef SDLINTERFACE_H_INCLUDED
#define SDLINTERFACE_H_INCLUDED

#include <SDL/SDL.h>
#include "baseinterface.h"

/**
  * This class provides implementation of basic SDL-based interface. If you
  * want to use window-creation facilities provided by SDL, whether you use
  * OpenGL or not, you should derive your interface from this class.
  *
  * This class does NOT implement any kind of login interface by itself.
  */
class SDLInterface : public BaseInterface
{
    public:
    SDLInterface();
    virtual ~SDLInterface();

    virtual void showSelf(); ///< Implements basic displaying of an SDL-based-interface area.
    virtual void hideSelf(); ///< Hides the SDL interface area.

    virtual void updateSelf(double k); ///< Generic event catcher for SDLInterface. Calls handleEvent() for parsing.

    virtual bool isCanceled() { return mPerformQuit; }

    virtual void blitSurface(SDL_Surface*s, int dx, int dy, int sx=0, int sy=0, int w=0, int h=0); ///< Blits the provided SDL surface onto the screen.

    protected:
    virtual void handleEvent(double k, const SDL_Event& event); ///< Default event handler for SDLInterface.
    SDL_Surface* mScreen; ///< SDL display surface
    bool mPerformQuit; ///< Should the SDL interface perform a quit as soon as possible?

};

#endif
